function x=punti_chebyshev(n,a,b)

% punti_chebyshev: Punti di Chebyshev (scalati in [a,b]).
%
% Dati di ingresso:
% n: numero naturale.
% a,b: estremi dell'intervallo [a,b]
%
% Dati di uscita:
% x: vettore di lunghezza (n+1), contenente i punti scalati di Chebyshev, 
%    unisolventi a grado "n".

if a >= b
    x=[]; return;
end

k=0:n;
x=(a+b)/2+((b-a)/2)*cos((2*k+1)*pi/(2*n+2));